@@ -19,5 +19,7 @@ class CPlatformAndroid : public CPlatformPosix
     /**\brief D'tor */
     ~CPlatformAndroid() override = default;
 
-    bool Init() override;
+    bool InitStageOne() override;
+    bool InitStageThree() override;
+    void PlatformSyslog() override;
 };
