@@ -9,8 +9,6 @@
 #pragma once
 
 #include <stdint.h>
-#include <string>
-#include <vector>
 
 #include <android/input.h>
 
@@ -24,7 +22,7 @@ public:
 
   static void SetHandleMediaKeys(bool enable) { m_handleMediaKeys = enable; }
   static void SetHandleSearchKeys(bool enable) { m_handleSearchKeys = enable; }
-  static void XBMC_Key(uint8_t code, uint16_t key, uint16_t modifiers, uint16_t unicode, bool up);
+  static void XBMC_Key(uint32_t code, uint16_t key, uint16_t modifiers, uint16_t unicode, bool up);
 
 protected:
   static bool m_handleMediaKeys;
