@@ -19,5 +19,7 @@ class CPlatformWin10 : public CPlatform
     /**\brief D'tor */
     ~CPlatformWin10() override = default;
 
-    bool Init() override;
+    bool InitStageOne() override;
+    void PlatformSyslog() override;
+    bool SupportsUserInstalledBinaryAddons() override;
 };
